package com.yunzhi.marketing.listener;

import com.alibaba.fastjson.JSONObject;
import com.yunzhi.marketing.common.VideoThreadDownLoad;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.redis.connection.Message;
import org.springframework.data.redis.connection.MessageListener;

import java.io.File;

public class VideoRedisListener implements MessageListener {
    public static final Logger LOG = LoggerFactory.getLogger(VideoRedisListener.class);

    private String videoLocalPath;

    public VideoRedisListener(String localPath) {
        videoLocalPath = localPath;
    }

    @Override
    public void onMessage(Message message, byte[] pattern) {
        LOG.info("订阅方收到录制文件信息:{}",message.toString());
        JSONObject jsonObject = JSONObject.parseObject(message.toString());
        String serverPath = jsonObject.getString("video_url");
        //构造文件下载到本地的路径
        String localPath = getLocalPath(jsonObject);
        //多线程下载文件
        VideoThreadDownLoad.downLoad(serverPath,localPath);
    }

    /**
     * 构建本地存储路径
     * @param jsonObject
     * @return
     */
    private String getLocalPath(JSONObject jsonObject) {
        String fileName = jsonObject.getString("stream_id") ;
        String dirName = fileName.split("_")[0];
        String localDir = videoLocalPath + File.separator +  dirName;
        File dir = new File(localDir);
        if (!dir.isDirectory()) {
            dir.mkdir();
        }
        String videoUrl = jsonObject.getString("video_url");
        String suffix = videoUrl.substring(videoUrl.lastIndexOf("."));
        String localPath = localDir + File.separator + fileName + "_" + jsonObject.getInteger("start_time") + "_" + jsonObject.getInteger("end_time") + suffix;
        return localPath;
    }
}
